@@ -8,6 +8,8 @@ from .interfaces import GraphImporterInterface
 
 from importlib import import_module
 
+import datetime
+
 def _try_import(moduleName: str, graphTypeName: str = 'Graph'):
     try:
         module = import_module(moduleName)
@@ -79,7 +81,7 @@ class GraphToolsGraphImporter(GraphImporterInterface):
             ),
             list(graph.edge_properties.keys())
         )
-        return nodes, edges, graph.is_directed()
+        return nodes, edges, graph.is_directed(), 'graph_tool'
 
 class Neo4jGraphImporter(GraphImporterInterface):
     """Class for importing graphs from the [neo4j](https://github.com/neo4j/neo4j-python-driver) package.
@@ -102,15 +104,32 @@ class Neo4jGraphImporter(GraphImporterInterface):
         else:
             return False
 
+
+    # neo4j datetime cannot be serialized automatically, so syncing it in the traitlet would fail
+    def _sanitizeNeo4jDateTime(self, kv):
+        key = kv[0]
+        value = kv[1]
+
+        neotime = _try_import('neo4j', 'time')
+
+        if (neotime is not None and neotime.DateTime is not None and isinstance(value, neotime.DateTime)): 
+            value = datetime.datetime(value.year, value.month, value.day,
+                                value.hour, value.minute, int(value.second),
+                                int(value.second * 1000000 % 1000000),
+                                tzinfo=value.tzinfo)
+
+        return (key, str(value))
+
     def _import(self, graph) -> Tuple[List[Dict], List[Dict], bool]:
         nodes = list(map(lambda neoNode: (
-            {"id": neoNode.id, "properties": {**dict(neoNode.items()), "label": ":".join(neoNode.labels)}}),
+            {"id": neoNode.id, "properties": {**dict(map(self._sanitizeNeo4jDateTime, neoNode.items())), "label": ":".join(neoNode.labels)}}),
                          graph.nodes))
+
         edges = list(map(lambda relationship: (
             {"id": relationship.id, "start": relationship.start_node.id, "end": relationship.end_node.id,
-             "properties": {**dict(relationship.items()), "label": relationship.type}}), graph.relationships))
+             "properties": {**dict(map(self._sanitizeNeo4jDateTime, relationship.items())), "label": relationship.type}}), graph.relationships))
 
-        return nodes, edges, True
+        return nodes, edges, True, 'neo4j'
 
 
 class IGraphGraphImporter(GraphImporterInterface):
@@ -151,7 +170,7 @@ class IGraphGraphImporter(GraphImporterInterface):
     def _import(self, graph) -> Tuple[List[Dict], List[Dict], bool]:
         nodes = self._collect_nodes(graph.vs)
         edges = self._collect_edges(graph.es)
-        return nodes, edges, graph.is_directed()
+        return nodes, edges, graph.is_directed(), 'igraph'
 
 
 def _set_label_attr(index: int, value: str, attr: Dict):
@@ -199,7 +218,7 @@ class NetworkxGraphImporter(GraphImporterInterface):
             _edge = dict(id=j, start=u_id, end=v_id, properties=attr)
             edges.append(_edge)
 
-        return nodes, edges, directed
+        return nodes, edges, directed, 'networkx'
 
 
 def _to_dict(self):
@@ -309,4 +328,4 @@ class PyGraphvizGraphImporter(GraphImporterInterface):
             _edge = self._build_edge(j, edge, node_name_to_id)
             edges.append(_edge)
 
-        return nodes, edges, graph.is_directed()
+        return nodes, edges, graph.is_directed(), 'pygraphviz'
